Class: Aws::Rekognition::Types::AgeRange
- Inherits:
-
Struct
- Object
- Struct
- Aws::Rekognition::Types::AgeRange
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rekognition/types.rb
Overview
Structure containing the estimated age range, in years, for a face.
Amazon Rekognition estimates an age range for faces detected in the input image. Estimated age ranges can overlap. A face of a 5-year-old might have an estimated range of 4-6, while the face of a 6-year-old might have an estimated range of 4-8.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#high ⇒ Integer
The highest estimated age.
-
#low ⇒ Integer
The lowest estimated age.
Instance Attribute Details
#high ⇒ Integer
The highest estimated age.
32 33 34 35 36 37 |
# File 'lib/aws-sdk-rekognition/types.rb', line 32 class AgeRange < Struct.new( :low, :high) SENSITIVE = [] include Aws::Structure end |
#low ⇒ Integer
The lowest estimated age.
32 33 34 35 36 37 |
# File 'lib/aws-sdk-rekognition/types.rb', line 32 class AgeRange < Struct.new( :low, :high) SENSITIVE = [] include Aws::Structure end |