Class: Aws::Rekognition::Types::CreateFaceLivenessSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Rekognition::Types::CreateFaceLivenessSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rekognition/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
Idempotent token is used to recognize the Face Liveness request.
-
#kms_key_id ⇒ String
The identifier for your AWS Key Management Service key (AWS KMS key).
-
#settings ⇒ Types::CreateFaceLivenessSessionRequestSettings
A session settings object.
Instance Attribute Details
#client_request_token ⇒ String
Idempotent token is used to recognize the Face Liveness request. If the same token is used with multiple CreateFaceLivenessSession requests, the same session is returned. This token is employed to avoid unintentionally creating the same session multiple times.
986 987 988 989 990 991 992 |
# File 'lib/aws-sdk-rekognition/types.rb', line 986 class CreateFaceLivenessSessionRequest < Struct.new( :kms_key_id, :settings, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier for your AWS Key Management Service key (AWS KMS key). Used to encrypt audit images and reference images.
986 987 988 989 990 991 992 |
# File 'lib/aws-sdk-rekognition/types.rb', line 986 class CreateFaceLivenessSessionRequest < Struct.new( :kms_key_id, :settings, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::CreateFaceLivenessSessionRequestSettings
A session settings object. It contains settings for the operation to be performed. For Face Liveness, it accepts OutputConfig and AuditImagesLimit.
986 987 988 989 990 991 992 |
# File 'lib/aws-sdk-rekognition/types.rb', line 986 class CreateFaceLivenessSessionRequest < Struct.new( :kms_key_id, :settings, :client_request_token) SENSITIVE = [] include Aws::Structure end |