Method: Aws::Rekognition::Types::CreateStreamProcessorRequest#notification_channel

Defined in:
lib/aws-sdk-rekognition/types.rb

#notification_channelTypes::StreamProcessorNotificationChannel

The Amazon Simple Notification Service topic to which Amazon Rekognition publishes the object detection results and completion status of a video analysis operation.

Amazon Rekognition publishes a notification the first time an object of interest or a person is detected in the video stream. For example, if Amazon Rekognition detects a person at second 2, a pet at second 4, and a person again at second 5, Amazon Rekognition sends 2 object class detected notifications, one for a person at second 2 and one for a pet at second 4.

Amazon Rekognition also publishes an an end-of-session notification with a summary when the stream processing session is complete.



1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-rekognition/types.rb', line 1264

class CreateStreamProcessorRequest < Struct.new(
  :input,
  :output,
  :name,
  :settings,
  :role_arn,
  :tags,
  :notification_channel,
  :kms_key_id,
  :regions_of_interest,
  :data_sharing_preference)
  SENSITIVE = []
  include Aws::Structure
end