Method: Aws::Rekognition::Types::DetectLabelsRequest#max_labels

Defined in:
lib/aws-sdk-rekognition/types.rb

#max_labelsInteger

Maximum number of labels you want the service to return in the response. The service returns the specified number of highest confidence labels. Only valid when GENERAL_LABELS is specified as a feature type in the Feature input parameter.

Returns:

  • (Integer)


2346
2347
2348
2349
2350
2351
2352
2353
2354
# File 'lib/aws-sdk-rekognition/types.rb', line 2346

class DetectLabelsRequest < Struct.new(
  :image,
  :max_labels,
  :min_confidence,
  :features,
  :settings)
  SENSITIVE = []
  include Aws::Structure
end