Class: Aws::Rekognition::Types::DetectModerationLabelsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rekognition/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_typesArray<Types::ContentType>

A list of predicted results for the type of content an image contains. For example, the image content might be from animation, sports, or a video game.



2485
2486
2487
2488
2489
2490
2491
2492
2493
# File 'lib/aws-sdk-rekognition/types.rb', line 2485

class DetectModerationLabelsResponse < Struct.new(
  :moderation_labels,
  :moderation_model_version,
  :human_loop_activation_output,
  :project_version,
  :content_types)
  SENSITIVE = []
  include Aws::Structure
end

#human_loop_activation_outputTypes::HumanLoopActivationOutput

Shows the results of the human in the loop evaluation.



2485
2486
2487
2488
2489
2490
2491
2492
2493
# File 'lib/aws-sdk-rekognition/types.rb', line 2485

class DetectModerationLabelsResponse < Struct.new(
  :moderation_labels,
  :moderation_model_version,
  :human_loop_activation_output,
  :project_version,
  :content_types)
  SENSITIVE = []
  include Aws::Structure
end

#moderation_labelsArray<Types::ModerationLabel>

Array of detected Moderation labels. For video operations, this includes the time, in milliseconds from the start of the video, they were detected.



2485
2486
2487
2488
2489
2490
2491
2492
2493
# File 'lib/aws-sdk-rekognition/types.rb', line 2485

class DetectModerationLabelsResponse < Struct.new(
  :moderation_labels,
  :moderation_model_version,
  :human_loop_activation_output,
  :project_version,
  :content_types)
  SENSITIVE = []
  include Aws::Structure
end

#moderation_model_versionString

Version number of the base moderation detection model that was used to detect unsafe content.



2485
2486
2487
2488
2489
2490
2491
2492
2493
# File 'lib/aws-sdk-rekognition/types.rb', line 2485

class DetectModerationLabelsResponse < Struct.new(
  :moderation_labels,
  :moderation_model_version,
  :human_loop_activation_output,
  :project_version,
  :content_types)
  SENSITIVE = []
  include Aws::Structure
end

#project_versionString

Identifier of the custom adapter that was used during inference. If during inference the adapter was EXPIRED, then the parameter will not be returned, indicating that a base moderation detection project version was used.



2485
2486
2487
2488
2489
2490
2491
2492
2493
# File 'lib/aws-sdk-rekognition/types.rb', line 2485

class DetectModerationLabelsResponse < Struct.new(
  :moderation_labels,
  :moderation_model_version,
  :human_loop_activation_output,
  :project_version,
  :content_types)
  SENSITIVE = []
  include Aws::Structure
end