Class: Aws::Rekognition::Types::DisassociateFacesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rekognition/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#disassociated_facesArray<Types::DisassociatedFace>

An array of DissociatedFace objects containing FaceIds that are successfully disassociated with the UserID is returned. Returned if the DisassociatedFaces action is successful.

Returns:



2674
2675
2676
2677
2678
2679
2680
# File 'lib/aws-sdk-rekognition/types.rb', line 2674

class DisassociateFacesResponse < Struct.new(
  :disassociated_faces,
  :unsuccessful_face_disassociations,
  :user_status)
  SENSITIVE = []
  include Aws::Structure
end

#unsuccessful_face_disassociationsArray<Types::UnsuccessfulFaceDisassociation>

An array of UnsuccessfulDisassociation objects containing FaceIds that are not successfully associated, along with the reasons for the failure to associate. Returned if the DisassociateFaces action is successful.

Returns:



2674
2675
2676
2677
2678
2679
2680
# File 'lib/aws-sdk-rekognition/types.rb', line 2674

class DisassociateFacesResponse < Struct.new(
  :disassociated_faces,
  :unsuccessful_face_disassociations,
  :user_status)
  SENSITIVE = []
  include Aws::Structure
end

#user_statusString

The status of an update made to a User. Reflects if the User has been updated for every requested change.

Returns:



2674
2675
2676
2677
2678
2679
2680
# File 'lib/aws-sdk-rekognition/types.rb', line 2674

class DisassociateFacesResponse < Struct.new(
  :disassociated_faces,
  :unsuccessful_face_disassociations,
  :user_status)
  SENSITIVE = []
  include Aws::Structure
end