Class: Aws::Rekognition::Types::FaceMatch

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rekognition/types.rb

Overview

Provides face metadata. In addition, it also provides the confidence in the match of this face with the input face.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#faceTypes::Face

Describes the face properties such as the bounding box, face ID, image ID of the source image, and external image ID that you assigned.



3115
3116
3117
3118
3119
3120
# File 'lib/aws-sdk-rekognition/types.rb', line 3115

class FaceMatch < Struct.new(
  :similarity,
  :face)
  SENSITIVE = []
  include Aws::Structure
end

#similarityFloat

Confidence in the match of this face with the input face.



3115
3116
3117
3118
3119
3120
# File 'lib/aws-sdk-rekognition/types.rb', line 3115

class FaceMatch < Struct.new(
  :similarity,
  :face)
  SENSITIVE = []
  include Aws::Structure
end