Class: Aws::Rekognition::Types::GetCelebrityRecognitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rekognition/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_idString

Job identifier for the required celebrity recognition analysis. You can get the job identifer from a call to StartCelebrityRecognition.



3347
3348
3349
3350
3351
3352
3353
3354
# File 'lib/aws-sdk-rekognition/types.rb', line 3347

class GetCelebrityRecognitionRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Maximum number of results to return per paginated call. The largest value you can specify is 1000. If you specify a value greater than 1000, a maximum of 1000 results is returned. The default value is 1000.



3347
3348
3349
3350
3351
3352
3353
3354
# File 'lib/aws-sdk-rekognition/types.rb', line 3347

class GetCelebrityRecognitionRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the previous response was incomplete (because there is more recognized celebrities to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of celebrities.



3347
3348
3349
3350
3351
3352
3353
3354
# File 'lib/aws-sdk-rekognition/types.rb', line 3347

class GetCelebrityRecognitionRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

Sort to use for celebrities returned in Celebrities field. Specify ID to sort by the celebrity identifier, specify TIMESTAMP to sort by the time the celebrity was recognized.



3347
3348
3349
3350
3351
3352
3353
3354
# File 'lib/aws-sdk-rekognition/types.rb', line 3347

class GetCelebrityRecognitionRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end