Class: Aws::Rekognition::Types::GetCelebrityRecognitionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rekognition/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#celebritiesArray<Types::CelebrityRecognition>

Array of celebrities recognized in the video.



3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
# File 'lib/aws-sdk-rekognition/types.rb', line 3400

class GetCelebrityRecognitionResponse < Struct.new(
  :job_status,
  :status_message,
  :video_metadata,
  :next_token,
  :celebrities,
  :job_id,
  :video,
  :job_tag)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

Job identifier for the celebrity recognition operation for which you want to obtain results. The job identifer is returned by an initial call to StartCelebrityRecognition.



3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
# File 'lib/aws-sdk-rekognition/types.rb', line 3400

class GetCelebrityRecognitionResponse < Struct.new(
  :job_status,
  :status_message,
  :video_metadata,
  :next_token,
  :celebrities,
  :job_id,
  :video,
  :job_tag)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The current status of the celebrity recognition job.



3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
# File 'lib/aws-sdk-rekognition/types.rb', line 3400

class GetCelebrityRecognitionResponse < Struct.new(
  :job_status,
  :status_message,
  :video_metadata,
  :next_token,
  :celebrities,
  :job_id,
  :video,
  :job_tag)
  SENSITIVE = []
  include Aws::Structure
end

#job_tagString

A job identifier specified in the call to StartCelebrityRecognition and returned in the job completion notification sent to your Amazon Simple Notification Service topic.



3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
# File 'lib/aws-sdk-rekognition/types.rb', line 3400

class GetCelebrityRecognitionResponse < Struct.new(
  :job_status,
  :status_message,
  :video_metadata,
  :next_token,
  :celebrities,
  :job_id,
  :video,
  :job_tag)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response is truncated, Amazon Rekognition Video returns this token that you can use in the subsequent request to retrieve the next set of celebrities.



3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
# File 'lib/aws-sdk-rekognition/types.rb', line 3400

class GetCelebrityRecognitionResponse < Struct.new(
  :job_status,
  :status_message,
  :video_metadata,
  :next_token,
  :celebrities,
  :job_id,
  :video,
  :job_tag)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

If the job fails, StatusMessage provides a descriptive error message.



3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
# File 'lib/aws-sdk-rekognition/types.rb', line 3400

class GetCelebrityRecognitionResponse < Struct.new(
  :job_status,
  :status_message,
  :video_metadata,
  :next_token,
  :celebrities,
  :job_id,
  :video,
  :job_tag)
  SENSITIVE = []
  include Aws::Structure
end

#videoTypes::Video

Video file stored in an Amazon S3 bucket. Amazon Rekognition video start operations such as StartLabelDetection use Video to specify a video for analysis. The supported file formats are .mp4, .mov and .avi.



3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
# File 'lib/aws-sdk-rekognition/types.rb', line 3400

class GetCelebrityRecognitionResponse < Struct.new(
  :job_status,
  :status_message,
  :video_metadata,
  :next_token,
  :celebrities,
  :job_id,
  :video,
  :job_tag)
  SENSITIVE = []
  include Aws::Structure
end

#video_metadataTypes::VideoMetadata

Information about a video that Amazon Rekognition Video analyzed. Videometadata is returned in every page of paginated responses from a Amazon Rekognition Video operation.



3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
# File 'lib/aws-sdk-rekognition/types.rb', line 3400

class GetCelebrityRecognitionResponse < Struct.new(
  :job_status,
  :status_message,
  :video_metadata,
  :next_token,
  :celebrities,
  :job_id,
  :video,
  :job_tag)
  SENSITIVE = []
  include Aws::Structure
end