Class: Aws::Rekognition::Types::GetContentModerationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rekognition/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregate_byString

Defines how to aggregate results of the StartContentModeration request. Default aggregation option is TIMESTAMPS. SEGMENTS mode aggregates moderation labels over time.



3447
3448
3449
3450
3451
3452
3453
3454
3455
# File 'lib/aws-sdk-rekognition/types.rb', line 3447

class GetContentModerationRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token,
  :sort_by,
  :aggregate_by)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The identifier for the inappropriate, unwanted, or offensive content moderation job. Use JobId to identify the job in a subsequent call to GetContentModeration.



3447
3448
3449
3450
3451
3452
3453
3454
3455
# File 'lib/aws-sdk-rekognition/types.rb', line 3447

class GetContentModerationRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token,
  :sort_by,
  :aggregate_by)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Maximum number of results to return per paginated call. The largest value you can specify is 1000. If you specify a value greater than 1000, a maximum of 1000 results is returned. The default value is 1000.



3447
3448
3449
3450
3451
3452
3453
3454
3455
# File 'lib/aws-sdk-rekognition/types.rb', line 3447

class GetContentModerationRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token,
  :sort_by,
  :aggregate_by)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the previous response was incomplete (because there is more data to retrieve), Amazon Rekognition returns a pagination token in the response. You can use this pagination token to retrieve the next set of content moderation labels.



3447
3448
3449
3450
3451
3452
3453
3454
3455
# File 'lib/aws-sdk-rekognition/types.rb', line 3447

class GetContentModerationRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token,
  :sort_by,
  :aggregate_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

Sort to use for elements in the ModerationLabelDetections array. Use TIMESTAMP to sort array elements by the time labels are detected. Use NAME to alphabetically group elements for a label together. Within each label group, the array element are sorted by detection confidence. The default sort is by TIMESTAMP.



3447
3448
3449
3450
3451
3452
3453
3454
3455
# File 'lib/aws-sdk-rekognition/types.rb', line 3447

class GetContentModerationRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token,
  :sort_by,
  :aggregate_by)
  SENSITIVE = []
  include Aws::Structure
end