Class: Aws::Rekognition::Types::GetTextDetectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rekognition/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_idString

Job identifier for the text detection operation for which you want results returned. You get the job identifer from an initial call to StartTextDetection.



4220
4221
4222
4223
4224
4225
4226
# File 'lib/aws-sdk-rekognition/types.rb', line 4220

class GetTextDetectionRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Maximum number of results to return per paginated call. The largest value you can specify is 1000.



4220
4221
4222
4223
4224
4225
4226
# File 'lib/aws-sdk-rekognition/types.rb', line 4220

class GetTextDetectionRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the previous response was incomplete (because there are more labels to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of text.



4220
4221
4222
4223
4224
4225
4226
# File 'lib/aws-sdk-rekognition/types.rb', line 4220

class GetTextDetectionRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end