Class: Aws::Rekognition::Types::LimitExceededException
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::Rekognition::Types::LimitExceededException
- Defined in:
- lib/aws-sdk-rekognition/types.rb
Overview
An Amazon Rekognition service limit was exceeded. For example, if you
start too many jobs concurrently, subsequent calls to start operations
(ex: StartLabelDetection) will raise a LimitExceededException
exception (HTTP status code: 400) until the number of concurrently
running jobs is below the Amazon Rekognition service limit.