Class: Aws::Rekognition::Types::ListDatasetEntriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Rekognition::Types::ListDatasetEntriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rekognition/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contains_labels ⇒ Array<String>
Specifies a label filter for the response.
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) for the dataset that you want to use.
-
#has_errors ⇒ Boolean
Specifies an error filter for the response.
-
#labeled ⇒ Boolean
Specify
trueto get only the JSON Lines where the image is labeled. -
#max_results ⇒ Integer
The maximum number of results to return per paginated call.
-
#next_token ⇒ String
If the previous response was incomplete (because there is more results to retrieve), Amazon Rekognition Custom Labels returns a pagination token in the response.
-
#source_ref_contains ⇒ String
If specified,
ListDatasetEntriesonly returns JSON Lines where the value ofSourceRefContainsis part of thesource-reffield.
Instance Attribute Details
#contains_labels ⇒ Array<String>
Specifies a label filter for the response. The response includes an
entry only if one or more of the labels in ContainsLabels exist in
the entry.
4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-rekognition/types.rb', line 4997 class ListDatasetEntriesRequest < Struct.new( :dataset_arn, :contains_labels, :labeled, :source_ref_contains, :has_errors, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) for the dataset that you want to use.
4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-rekognition/types.rb', line 4997 class ListDatasetEntriesRequest < Struct.new( :dataset_arn, :contains_labels, :labeled, :source_ref_contains, :has_errors, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#has_errors ⇒ Boolean
Specifies an error filter for the response. Specify True to only
include entries that have errors.
4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-rekognition/types.rb', line 4997 class ListDatasetEntriesRequest < Struct.new( :dataset_arn, :contains_labels, :labeled, :source_ref_contains, :has_errors, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#labeled ⇒ Boolean
Specify true to get only the JSON Lines where the image is
labeled. Specify false to get only the JSON Lines where the image
isn't labeled. If you don't specify Labeled,
ListDatasetEntries returns JSON Lines for labeled and unlabeled
images.
4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-rekognition/types.rb', line 4997 class ListDatasetEntriesRequest < Struct.new( :dataset_arn, :contains_labels, :labeled, :source_ref_contains, :has_errors, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per paginated call. The largest value you can specify is 100. If you specify a value greater than 100, a ValidationException error occurs. The default value is 100.
4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-rekognition/types.rb', line 4997 class ListDatasetEntriesRequest < Struct.new( :dataset_arn, :contains_labels, :labeled, :source_ref_contains, :has_errors, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was incomplete (because there is more results to retrieve), Amazon Rekognition Custom Labels returns a pagination token in the response. You can use this pagination token to retrieve the next set of results.
4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-rekognition/types.rb', line 4997 class ListDatasetEntriesRequest < Struct.new( :dataset_arn, :contains_labels, :labeled, :source_ref_contains, :has_errors, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#source_ref_contains ⇒ String
If specified, ListDatasetEntries only returns JSON Lines where the
value of SourceRefContains is part of the source-ref field. The
source-ref field contains the Amazon S3 location of the image. You
can use SouceRefContains for tasks such as getting the JSON Line
for a single image, or gettting JSON Lines for all images within a
specific folder.
4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/aws-sdk-rekognition/types.rb', line 4997 class ListDatasetEntriesRequest < Struct.new( :dataset_arn, :contains_labels, :labeled, :source_ref_contains, :has_errors, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |