Class: Aws::Rekognition::Waiters::ProjectVersionTrainingCompleted
- Inherits:
-
Object
- Object
- Aws::Rekognition::Waiters::ProjectVersionTrainingCompleted
- Defined in:
- lib/aws-sdk-rekognition/waiters.rb,
sig/waiters.rbs
Overview
Wait until the ProjectVersion training completes.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ProjectVersionTrainingCompleted
constructor
A new instance of ProjectVersionTrainingCompleted.
-
#wait(params = {}) ⇒ Types::DescribeProjectVersionsResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ProjectVersionTrainingCompleted
Returns a new instance of ProjectVersionTrainingCompleted.
131 132 |
# File 'lib/aws-sdk-rekognition/waiters.rb', line 131
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
163 164 165 |
# File 'lib/aws-sdk-rekognition/waiters.rb', line 163 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeProjectVersionsResponse
Returns a response object which responds to the following methods:
- #project_version_descriptions => Array<Types::ProjectVersionDescription>
- #next_token => String
158 |
# File 'lib/aws-sdk-rekognition/waiters.rb', line 158
def wait: (
|