Method: Aws::Rekognition::Types::DetectCustomLabelsRequest#project_version_arn
- Defined in:
- lib/aws-sdk-rekognition/types.rb
#project_version_arn ⇒ String
The ARN of the model version that you want to use. Only models associated with Custom Labels projects accepted by the operation. If a provided ARN refers to a model version associated with a project for a different feature type, then an InvalidParameterException is returned.
2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-rekognition/types.rb', line 2093 class DetectCustomLabelsRequest < Struct.new( :project_version_arn, :image, :max_results, :min_confidence) SENSITIVE = [] include Aws::Structure end |