Method: Aws::Rekognition::Types::DetectLabelsRequest#image
- Defined in:
- lib/aws-sdk-rekognition/types.rb
#image ⇒ Types::Image
The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes is not supported. Images stored in an S3 Bucket do not need to be base64-encoded.
If you are using an AWS SDK to call Amazon Rekognition, you might not need to base64-encode image bytes passed using the Bytes field. For more information, see Images in the Amazon Rekognition developer guide.
2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-rekognition/types.rb', line 2346 class DetectLabelsRequest < Struct.new( :image, :max_labels, :min_confidence, :features, :settings) SENSITIVE = [] include Aws::Structure end |