Method: Aws::Rekognition::Types::DetectLabelsRequest#settings
- Defined in:
- lib/aws-sdk-rekognition/types.rb
#settings ⇒ Types::DetectLabelsSettings
A list of the filters to be applied to returned detected labels and image properties. Specified filters can be inclusive, exclusive, or a combination of both. Filters can be used for individual labels or label categories. The exact label names or label categories must be supplied. For a full list of labels and label categories, see [Detecting labels].
2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-rekognition/types.rb', line 2346 class DetectLabelsRequest < Struct.new( :image, :max_labels, :min_confidence, :features, :settings) SENSITIVE = [] include Aws::Structure end |