Method: Aws::Rekognition::Types::StartTextDetectionRequest#client_request_token
- Defined in:
- lib/aws-sdk-rekognition/types.rb
#client_request_token ⇒ String
Idempotent token used to identify the start request. If you use the same token with multiple StartTextDetection requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidentaly started more than once.
7553 7554 7555 7556 7557 7558 7559 7560 7561 |
# File 'lib/aws-sdk-rekognition/types.rb', line 7553 class StartTextDetectionRequest < Struct.new( :video, :client_request_token, :notification_channel, :job_tag, :filters) SENSITIVE = [] include Aws::Structure end |